@@ -1,7 +1,17 @@
 package Net::CIDR::MobileJP::Scraper;
 use strict;
 use warnings;
-use Module::Pluggable::Fast name => 'plugins', search => [qw/Net::CIDR::MobileJP::Scraper::Plugin/];
+use WWW::MobileCarrierJP::DoCoMo::CIDR;
+use WWW::MobileCarrierJP::EZWeb::CIDR;
+use WWW::MobileCarrierJP::AirHPhone::CIDR;
+use WWW::MobileCarrierJP::ThirdForce::CIDR;
+
+my $short_name_for = +{
+    DoCoMo     => 'I',
+    EZWeb      => 'E',
+    AirHPhone  => 'H',
+    ThirdForce => 'V',
+};
 
 sub new { bless {}, shift }
 
@@ -9,8 +19,10 @@ sub run {
     my ($self, ) = @_;
 
     my $result;
-    for my $plugin ($self->plugins) {
-        $result->{$plugin->carrier} = $plugin->run;
+    for my $carrier (qw/DoCoMo EZWeb AirHPhone ThirdForce/) {
+        my $class = "WWW::MobileCarrierJP::${carrier}::CIDR";
+        my $dat = $class->scrape;
+        $result->{$short_name_for->{$carrier}} = [map { "$_->{ip}$_->{subnetmask}" } @$dat];
     }
     return $result;
 }
